"use strict";

/* eslint-disable no-console */

import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
function transformThemeToStyles(theme) {
  const defaultBackground = theme.colors?.['editor.background'];
  const foreground = theme.colors?.['editor.foreground'];
  console.log('[SyntaxHighlighter] Theme colors:', {
    background: defaultBackground,
    foreground,
    allColors: theme.colors
  });
  const styles = StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%'
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    baseToken: {
      fontFamily: monospaceFont
    }
  });
  const colorStyles = new Map();
  return {
    base: styles,
    background: defaultBackground,
    getTokenStyle: token => {
      const key = `${token.color || ''}-${token.fontStyle || ''}`;
      if (!colorStyles.has(key)) {
        const style = {
          color: token.color || foreground,
          fontStyle: token.fontStyle ? 'italic' : 'normal',
          fontWeight: token.fontStyle ? 'bold' : 'normal'
        };
        console.log('[SyntaxHighlighter] Created new token style:', {
          key,
          token,
          style
        });
        colorStyles.set(key, style);
      }
      return colorStyles.get(key);
    }
  };
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  console.log('[SyntaxHighlighter] Input:', {
    text: text?.slice(0, 100),
    // First 100 chars for preview
    language,
    languageId: languageId || String(language),
    hasTheme: !!theme
  });
  const result = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme
  });
  console.log('[SyntaxHighlighter] Hook result:', {
    hasTokens: !!result.tokens,
    tokenCount: result.tokens?.length || 0,
    firstLineTokenCount: result.tokens?.[0]?.length || 0,
    error: result.error
  });
  const {
    tokens
  } = result;
  const styles = useMemo(() => {
    console.log('[SyntaxHighlighter] Creating styles with theme:', {
      hasTheme: !!theme,
      background: theme?.colors?.['editor.background'],
      foreground: theme?.colors?.['editor.foreground']
    });
    return transformThemeToStyles(theme);
  }, [theme]);
  if (!tokens || tokens.length === 0) {
    console.warn('[SyntaxHighlighter] No tokens generated, falling back to plain text');
    return /*#__PURE__*/_jsx(ScrollView, {
      horizontal: true,
      ...scrollViewProps,
      style: [styles.base.scrollView, scrollViewProps?.style],
      contentContainerStyle: [styles.base.codeContainer, {
        backgroundColor: theme?.colors?.['editor.background'] || '#1e1e1e'
      }, scrollViewProps?.contentContainerStyle, containerStyle],
      children: /*#__PURE__*/_jsx(View, {
        onStartShouldSetResponder: () => true,
        children: /*#__PURE__*/_jsx(View, {
          style: styles.base.lineContainer,
          children: /*#__PURE__*/_jsx(Text, {
            style: [styles.base.baseToken, {
              fontSize
            }, textStyle],
            children: text
          })
        })
      })
    });
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [styles.base.scrollView, scrollViewProps?.style],
    contentContainerStyle: [styles.base.codeContainer, {
      backgroundColor: theme?.colors?.['editor.background'] || '#1e1e1e'
    }, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, rowIndex) => /*#__PURE__*/_jsx(View, {
        style: [styles.base.lineContainer, {
          backgroundColor: theme?.colors?.['editor.background'] || '#1e1e1e'
        }],
        children: line.map((token, tokenIndex) => {
          const tokenStyle = styles.getTokenStyle(token);
          if (rowIndex === 0 && tokenIndex === 0) {
            console.log('[SyntaxHighlighter] First token:', {
              content: token.content,
              color: token.color,
              fontStyle: token.fontStyle,
              computedStyle: tokenStyle
            });
          }
          return /*#__PURE__*/_jsx(Text, {
            style: [styles.base.baseToken, tokenStyle, {
              fontSize
            }, textStyle],
            children: token.content
          }, `${rowIndex}-${tokenIndex}`);
        })
      }, rowIndex))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map