/* eslint-disable no-console */
import type { ThemedToken, ThemeRegistration } from '@shikijs/types'
import type { ScrollViewProps, StyleProp, TextStyle, ViewStyle } from 'react-native'
import type { SyntaxHighlighterProps } from 'src/types/shiki'
import React, { useMemo } from 'react'
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native'
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter'

const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace',
})

function transformThemeToStyles(theme: ThemeRegistration) {
  const defaultBackground = theme.colors?.['editor.background']
  const foreground = theme.colors?.['editor.foreground']

  console.log('[SyntaxHighlighter] Theme colors:', {
    background: defaultBackground,
    foreground,
    allColors: theme.colors,
  })

  const styles = StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20,
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%',
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap',
    },
    baseToken: {
      fontFamily: monospaceFont,
    },
  })

  const colorStyles = new Map<string, TextStyle>()

  return {
    base: styles,
    background: defaultBackground,
    getTokenStyle: (token: ThemedToken): TextStyle => {
      const key = `${token.color || ''}-${token.fontStyle || ''}`

      if (!colorStyles.has(key)) {
        const style: TextStyle = {
          color: token.color || foreground,
          fontStyle: (token.fontStyle ? 'italic' : 'normal') as 'italic' | 'normal',
          fontWeight: token.fontStyle ? 'bold' : 'normal',
        }
        console.log('[SyntaxHighlighter] Created new token style:', { key, token, style })
        colorStyles.set(key, style)
      }

      return colorStyles.get(key)!
    },
  }
}

interface Props extends SyntaxHighlighterProps {
  scrollViewProps?: ScrollViewProps
  textStyle?: StyleProp<TextStyle>
  containerStyle?: StyleProp<ViewStyle>
}

const SyntaxHighlighter: React.FC<Props> = ({ text, language, languageId, theme, fontSize = 14, scrollViewProps, textStyle, containerStyle }) => {
  console.log('[SyntaxHighlighter] Input:', {
    text: text?.slice(0, 100), // First 100 chars for preview
    language,
    languageId: languageId || String(language),
    hasTheme: !!theme,
  })

  const result = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme,
  })

  console.log('[SyntaxHighlighter] Hook result:', {
    hasTokens: !!result.tokens,
    tokenCount: result.tokens?.length || 0,
    firstLineTokenCount: result.tokens?.[0]?.length || 0,
    error: result.error,
  })

  const { tokens } = result

  const styles = useMemo(() => {
    console.log('[SyntaxHighlighter] Creating styles with theme:', {
      hasTheme: !!theme,
      background: theme?.colors?.['editor.background'],
      foreground: theme?.colors?.['editor.foreground'],
    })
    return transformThemeToStyles(theme as ThemeRegistration)
  }, [theme])

  if (!tokens || tokens.length === 0) {
    console.warn('[SyntaxHighlighter] No tokens generated, falling back to plain text')
    return (
      <ScrollView
        horizontal
        {...scrollViewProps}
        style={[styles.base.scrollView, scrollViewProps?.style]}
        contentContainerStyle={[styles.base.codeContainer, { backgroundColor: theme?.colors?.['editor.background'] || '#1e1e1e' }, scrollViewProps?.contentContainerStyle, containerStyle]}
      >
        <View onStartShouldSetResponder={() => true}>
          <View style={styles.base.lineContainer}>
            <Text style={[styles.base.baseToken, { fontSize }, textStyle]}>{text}</Text>
          </View>
        </View>
      </ScrollView>
    )
  }

  return (
    <ScrollView
      horizontal
      {...scrollViewProps}
      style={[styles.base.scrollView, scrollViewProps?.style]}
      contentContainerStyle={[styles.base.codeContainer, { backgroundColor: theme?.colors?.['editor.background'] || '#1e1e1e' }, scrollViewProps?.contentContainerStyle, containerStyle]}
    >
      <View onStartShouldSetResponder={() => true}>
        {tokens.map((line, rowIndex) => (
          <View key={rowIndex} style={[styles.base.lineContainer, { backgroundColor: theme?.colors?.['editor.background'] || '#1e1e1e' }]}>
            {line.map((token, tokenIndex) => {
              const tokenStyle = styles.getTokenStyle(token)
              if (rowIndex === 0 && tokenIndex === 0) {
                console.log('[SyntaxHighlighter] First token:', {
                  content: token.content,
                  color: token.color,
                  fontStyle: token.fontStyle,
                  computedStyle: tokenStyle,
                })
              }
              return (
                <Text key={`${rowIndex}-${tokenIndex}`} style={[styles.base.baseToken, tokenStyle, { fontSize }, textStyle]}>
                  {token.content}
                </Text>
              )
            })}
          </View>
        ))}
      </View>
    </ScrollView>
  )
}

export default SyntaxHighlighter
